FlutterSoundPlayerPlatform class abstract
The interface that implementations of flutter_soundPlayer must implement.
Platform implementations should extend this class rather than implement it as url_launcher
does not consider newly added methods to be breaking changes. Extending this class
(using extends) ensures that the subclass will get the default implementation, while
platform implementations that implements this interface will be broken by newly added
FlutterSoundPlayerPlatform methods.
- Inheritance
-
- Object
- PlatformInterface
- FlutterSoundPlayerPlatform
- Implementers
Constructors
- FlutterSoundPlayerPlatform()
- Constructs a UrlLauncherPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
closePlayer(
FlutterSoundPlayerCallback callback) → Future< int> -
closeSession(
FlutterSoundPlayerCallback aSession) → void -
feed(
FlutterSoundPlayerCallback callback, {required Uint8List data}) → Future< int> -
feedFloat32(
FlutterSoundPlayerCallback callback, {required List< Float32List> data}) → Future<int> -
feedInt16(
FlutterSoundPlayerCallback callback, {required List< Int16List> data}) → Future<int> -
findSession(
FlutterSoundPlayerCallback aSession) → int -
getPlayerState(
FlutterSoundPlayerCallback callback) → Future< int> -
getProgress(
FlutterSoundPlayerCallback callback) → Future< Map< String, Duration> > -
getResourcePath(
FlutterSoundPlayerCallback callback) → Future< String> -
getSession(
int slotno) → FlutterSoundPlayerCallback -
initPlugin(
) → Future< bool> -
isDecoderSupported(
FlutterSoundPlayerCallback callback, {required Codec codec}) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openPlayer(
FlutterSoundPlayerCallback callback, {required Level logLevel}) → Future< int> -
openSession(
FlutterSoundPlayerCallback aSession) → void -
pausePlayer(
FlutterSoundPlayerCallback callback) → Future< int> -
resetPlugin(
FlutterSoundPlayerCallback callback) → Future< void> ? -
resumePlayer(
FlutterSoundPlayerCallback callback) → Future< int> -
seekToPlayer(
FlutterSoundPlayerCallback callback, {Duration? duration}) → Future< int> -
setLogLevel(
FlutterSoundPlayerCallback callback, Level loglevel) → Future< void> ? -
setSpeed(
FlutterSoundPlayerCallback callback, {required double speed}) → Future< int> -
setSubscriptionDuration(
FlutterSoundPlayerCallback callback, {Duration? duration}) → Future< int> -
setVolume(
FlutterSoundPlayerCallback callback, {required double volume}) → Future< int> -
setVolumePan(
FlutterSoundPlayerCallback callback, {double? volume, double? pan}) → Future< int> -
startPlayer(
FlutterSoundPlayerCallback callback, {bool interleaved = true, Codec? codec, Uint8List? fromDataBuffer, String? fromURI, int? numChannels, int? sampleRate, int bufferSize = 8189}) → Future< int> -
startPlayerFromMic(
FlutterSoundPlayerCallback callback, {int? numChannels, int? sampleRate, int bufferSize = 8192, bool enableVoiceProcessing = false}) → Future< int> - @deprecated
-
startPlayerFromStream(
FlutterSoundPlayerCallback callback, {Codec codec = Codec.pcm16, bool interleaved = true, int numChannels = 1, int sampleRate = 16000, int bufferSize = 8192}) → Future< int> -
stopPlayer(
FlutterSoundPlayerCallback callback) → Future< int> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterSoundPlayerPlatform
-
The default instance of FlutterSoundPlayerPlatform to use.
getter/setter pair