FlutterSoundRecorderPlatform class abstract
The interface that implementations of url_launcher must implement.
Platform implementations should extend this class rather than implement it as url_launcher
does not consider newly added methods to be breaking changes. Extending this class
(using extends) ensures that the subclass will get the default implementation, while
platform implementations that implements this interface will be broken by newly added
FlutterSoundPlatform methods.
- Inheritance
-
- Object
- PlatformInterface
- FlutterSoundRecorderPlatform
- Implementers
Constructors
- FlutterSoundRecorderPlatform()
- Constructs a UrlLauncherPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- recorderState → RecorderState
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
closeRecorder(
FlutterSoundRecorderCallback callback) → Future< void> -
closeSession(
FlutterSoundRecorderCallback aSession) → void -
deleteRecord(
FlutterSoundRecorderCallback callback, String path) → Future< bool?> -
findSession(
FlutterSoundRecorderCallback aSession) → int -
getRecordURL(
FlutterSoundRecorderCallback callback, String path) → Future< String?> -
getSampleRate(
FlutterSoundRecorderCallback callback) → int -
getSession(
int slotno) → FlutterSoundRecorderCallback? -
initPlugin(
) → Future< bool> -
isEncoderSupported(
FlutterSoundRecorderCallback callback, {required Codec codec}) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openRecorder(
FlutterSoundRecorderCallback callback, {required Level logLevel}) → Future< void> -
openSession(
FlutterSoundRecorderCallback aSession) → void -
pauseRecorder(
FlutterSoundRecorderCallback callback) → Future< void> -
requestData(
FlutterSoundRecorderCallback callback) → void -
resetPlugin(
FlutterSoundRecorderCallback callback) → Future< void> ? -
resumeRecorder(
FlutterSoundRecorderCallback callback) → Future< void> -
setLogLevel(
FlutterSoundRecorderCallback callback, Level loglevel) → Future< void> ? -
setSubscriptionDuration(
FlutterSoundRecorderCallback callback, {Duration? duration}) → Future< void> -
startRecorder(
FlutterSoundRecorderCallback callback, {Codec? codec, String? path, int sampleRate = 44100, int numChannels = 1, int bitRate = 16000, int bufferSize = 8192, Duration timeSlice = Duration.zero, bool enableVoiceProcessing = false, bool interleaved = true, required bool toStream, AudioSource? audioSource, bool enableNoiseSuppression = false, bool enableEchoCancellation = true}) → Future< void> -
stopRecorder(
FlutterSoundRecorderCallback callback) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterSoundRecorderPlatform
-
The default instance of FlutterSoundRecorderPlatform to use.
getter/setter pair